#!/bin/bash
# Script to quickly create a sub-theme.

# Function to display error messages.
displayError() {
    echo -e "\033[41m$1\033[0m\033[K"
}

# Function to exit if an error occurs.
exitIfError() {
    if [ $1 -ne 0 ]; then
        displayError "Error: $2"
        exit 1
    fi
}

# Display script information.
echo '
+------------------------------------------------------------------------+
| Use this script to quickly create a seeds_ui sub-theme.               |
| Instructions:                                                         |
| - The seeds_ui theme folder must be in the contrib folder.            |
+------------------------------------------------------------------------+
'

# Variables
SUBTHEME_SOURCE="$( cd "$( dirname "${BASH_SOURCE[0]}" )" >/dev/null 2>&1 && pwd )/../subtheme"

# Get theme information.
read -p 'Enter the machine name of your custom theme (e.g., hello_world): ' CUSTOM_SEEDS_THEME
if [ -z "$CUSTOM_SEEDS_THEME" ]; then
    displayError "Custom theme machine name cannot be empty."
    exit 1
fi

read -p 'Enter your theme name (e.g., Hello World): ' CUSTOM_SEEDS_THEME_NAME
if [ -z "$CUSTOM_SEEDS_THEME_NAME" ]; then
    displayError "Theme name cannot be empty."
    exit 1
fi

read -p 'Enter the destination directory (e.g., /var/www/html/my_project/public_html/themes): ' THEMES_DIRECTORY
if [ -z "$THEMES_DIRECTORY" ]; then
    displayError "Destination directory cannot be empty."
    exit 1
fi

# Create sub-theme directory.
DESTINATION_PATH="$THEMES_DIRECTORY/$CUSTOM_SEEDS_THEME"
if [ -d "$DESTINATION_PATH" ]; then
    displayError "The directory $DESTINATION_PATH already exists. Please choose a different name."
    exit 1
fi

echo "Copying sub-theme to $DESTINATION_PATH..."
cp -r "$SUBTHEME_SOURCE" "$DESTINATION_PATH"
exitIfError $? "Failed to copy the sub-theme to $DESTINATION_PATH."

cd "$DESTINATION_PATH" || exitIfError $? "Failed to navigate to $DESTINATION_PATH."

# Rename files containing "THEMENAME".
echo "Renaming theme files..."
for file in *THEMENAME.*; do mv "$file" "${file//THEMENAME/$CUSTOM_SEEDS_THEME}"; done
for file in config/*/*THEMENAME*; do mv "$file" "${file//THEMENAME/$CUSTOM_SEEDS_THEME}"; done

# Replace occurrences of "THEMENAME" in files.
echo "Replacing placeholders in theme files..."
grep -Rl . . | xargs sed -i "s/THEMENAME/$CUSTOM_SEEDS_THEME/g"
exitIfError $? "Failed to replace placeholders in theme files."

# Install dependencies and build theme assets.
echo "Installing dependencies and building theme assets..."
npm install &>/dev/null
exitIfError $? "npm install failed."

npm run css &>/dev/null
exitIfError $? "npm run css failed."

# Enable theme in Drupal and set as default.
echo "Enabling and setting the theme as default in Drupal..."
../../../bin/drush theme:enable "$CUSTOM_SEEDS_THEME" -y
pwd
exitIfError $? "Failed to enable the theme."

../../../bin/drush config-set system.theme default "$CUSTOM_SEEDS_THEME" -y
exitIfError $? "Failed to set the theme as default."

echo -e "\033[42mSub-theme $CUSTOM_SEEDS_THEME successfully created and enabled!\033[0m"
